NAME

PAGI::App::Storage::Abstract - Storage::Abstract for PAGI

SYNOPSIS

use PAGI::App::Storage::Abstract;

my $app1 = PAGI::App::Storage::Abstract->new(
		storage_config => {
				driver => 'directory',
				directory => '/some/dir',
		},
)->to_app;

DESCRIPTION

This module is a PAGI app to serve static files with Storage::Abstract. See its documentation to understand how to properly configure the app in the constructor.

Upon constructing and mounting the application, it starts serving static files right away - no extra steps are required.

Beta quality: this module will remain beta as long as PAGI itself is not fully stabilized. Moreover, its interface may change if a base class for PAGI apps is introduced.

SEE ALSO

Plack::App::Storage::Abstract

AUTHOR

Bartosz Jarzyna <bbrtj.pro@gmail.com>

COPYRIGHT AND LICENSE

Copyright (C) 2026 by Bartosz Jarzyna

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.